@@ -13,6 +13,8 @@ from .data_point_origin import DataPointOrigin
 from .data_point_request import DataPointRequest
 from .data_point_response_base import DataPointResponseBase
 from .day_data_by_hour_transfer import DayDataByHourTransfer
+from .day_period_data_bucket import DayPeriodDataBucket
+from .day_period_data_point_data import DayPeriodDataPointData
 from .en_data_bucket_state import EnDataBucketState
 from .en_data_point_existence_dto import EnDataPointExistenceDTO
 from .en_data_point_state_dto import EnDataPointStateDTO
@@ -23,7 +25,9 @@ from .file_origin import FileOrigin
 from .get_constant_response import GetConstantResponse
 from .get_data_request import GetDataRequest
 from .get_data_response import GetDataResponse
+from .get_day_period_response import GetDayPeriodResponse
 from .get_series_response import GetSeriesResponse
+from .get_week_period_response import GetWeekPeriodResponse
 from .gnista_unit_response import GnistaUnitResponse
 from .problem_details import ProblemDetails
 from .problem_details_extensions import ProblemDetailsExtensions
@@ -40,3 +44,5 @@ from .update_day_period_request import UpdateDayPeriodRequest
 from .update_time_series_request import UpdateTimeSeriesRequest
 from .update_week_period_request import UpdateWeekPeriodRequest
 from .week_data_transfere import WeekDataTransfere
+from .week_period_data_bucket import WeekPeriodDataBucket
+from .week_period_data_point_data import WeekPeriodDataPointData
